Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEnvBool ¶
GetEnvBool gets the environment variable for a key and if that env-var hasn't been set it returns the default value
func GetEnvFloat ¶
GetEnvFloat gets the environment variable for a key and if that env-var hasn't been set it returns the default value. This function uses bitSize of 64 to convert string to float64.
func GetEnvInt ¶
GetEnvInt gets the environment variable for a key and if that env-var hasn't been set it returns the default value. This function is equivalent to ParseInt(s, 10, 0) to convert env-vars to type int
func GetEnvString ¶
GetEnvString gets the environment variable for a key and if that env-var hasn't been set it returns the default value
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.